'----------------------------------------------------------------------------
'
'                           CLONG.BAS
'                             1/1/90
'
'                 Written by: Mike Schoonmaker
'                             19 Vierra Court
'                             Sacramento, CA  95831
'                             (916) 429-0633
'
'             Purpose: Convert String of numbers in decimal
'                      notation to a LONG INTEGER for quick
'                      processing, and use in assy. routines
'                      that do not support floating point numbers.
'                      Also, accuracy of calculations is much
'                      higher than with floating point values.
'                 
'
'      Calling syntax: Number& = CLONG&(DecNo$, NumDigits%)
'
'                      where DecNo$ is a string of the decimal
'                      number to be converted, and NumDigits%
'                      is an integer indicating how many digits
'                      to shift. Displaying or printing the number
'                      would be done with "PRINT USING" or the
'                      PROBAS "NumFormat" routine.
'
'                      Could easily be used in an accounting program
'                      where speed AND accuracy is of the essence.
'
'                      Since this has been written as a function, it
'                      must be DECLARE'd before it can be used.
'                                 as in:
'                      DECLARE FUNCTION CLong& (DecNo$, NumDigits%)
'----------------------------------------------------------------------------

DEFINT A-Z
FUNCTION CLong& (DecNo$, NumDigits%)

   Length% = LEN(DecNo$)            'count total characters
   PtLoc% = INSTR(DecNo$, ".")      'locate decimal point position
 
   ST$ = DecNo$: CH$ = "."
   CALL STRIPCHAR(ST$, CH$, SLEN)   'strip out the decimal point
   DecNo$ = LEFT$(ST$, SLEN)        'strip blank left by 'STRIPCHAR'
 
   FOR x% = 1 TO NumDigits%         'develop string of "0"s to add
      Zeros$ = Zeros$ + "0"
   NEXT
 
   DecNo$ = DecNo$ + Zeros$         'add string of appropriate number of Zeros
 
   IF PtLoc% < 1 THEN               'if no decimal places then...
      CLong& = VAL(DecNo$)
   ELSE                             'if decimal places then...
      CLong& = VAL(LEFT$(DecNo$, PtLoc% + (NumDigits% - 1)))
   END IF

END FUNCTION

